@@ -13,6 +13,15 @@ class BaseDistance(ModuleWithRecords):
         self.power = power
         self.is_inverted = is_inverted
         self.add_to_recordable_attributes(list_of_names=["p", "power"], is_stat=False)
+        self.add_to_recordable_attributes(
+            list_of_names=[
+                "initial_avg_query_norm",
+                "initial_avg_ref_norm",
+                "final_avg_query_norm",
+                "final_avg_ref_norm",
+            ],
+            is_stat=True,
+        )
 
     def forward(self, query_emb, ref_emb=None):
         self.reset_stats()
@@ -70,24 +79,14 @@ class BaseDistance(ModuleWithRecords):
     ):
         if self.collect_stats:
             with torch.no_grad():
-                stats_dict = {
-                    "initial_avg_query_norm": torch.mean(
-                        self.get_norm(query_emb)
-                    ).item(),
-                    "initial_avg_ref_norm": torch.mean(self.get_norm(ref_emb)).item(),
-                    "final_avg_query_norm": torch.mean(
-                        self.get_norm(query_emb_normalized)
-                    ).item(),
-                    "final_avg_ref_norm": torch.mean(
-                        self.get_norm(ref_emb_normalized)
-                    ).item(),
-                }
-                self.set_stats(stats_dict)
-
-    def set_stats(self, stats_dict):
-        for k, v in stats_dict.items():
-            self.add_to_recordable_attributes(name=k, is_stat=True)
-            setattr(self, k, v)
+                self.initial_avg_query_norm: torch.mean(self.get_norm(query_emb)).item()
+                self.initial_avg_ref_norm = torch.mean(self.get_norm(ref_emb)).item()
+                self.final_avg_query_norm = torch.mean(
+                    self.get_norm(query_emb_normalized)
+                ).item()
+                self.final_avg_ref_norm = torch.mean(
+                    self.get_norm(ref_emb_normalized)
+                ).item()
 
     def check_shapes(self, query_emb, ref_emb):
         if query_emb.ndim != 2 or (ref_emb is not None and ref_emb.ndim != 2):
