@@ -1,11 +1,10 @@
 from .angular_miner import AngularMiner
-from .base_miner import BaseMiner, BaseSubsetBatchMiner, BaseTupleMiner
+from .base_miner import BaseMiner
 from .batch_easy_hard_miner import BatchEasyHardMiner
 from .batch_hard_miner import BatchHardMiner
 from .distance_weighted_miner import DistanceWeightedMiner
 from .embeddings_already_packaged_as_triplets import EmbeddingsAlreadyPackagedAsTriplets
 from .hdc_miner import HDCMiner
-from .maximum_loss_miner import MaximumLossMiner
 from .multi_similarity_miner import MultiSimilarityMiner
 from .pair_margin_miner import PairMarginMiner
 from .triplet_margin_miner import TripletMarginMiner
