@@ -5,33 +5,6 @@ from ..utils.module_with_records_and_reducer import ModuleWithRecordsAndDistance
 
 
 class BaseMiner(ModuleWithRecordsAndDistance):
-    def mine(self, embeddings, labels, ref_emb, ref_labels):
-        raise NotImplementedError
-
-    def output_assertion(self, output):
-        raise NotImplementedError
-
-    def forward(self, embeddings, labels, ref_emb=None, ref_labels=None):
-        """
-        Args:
-            embeddings: tensor of size (batch_size, embedding_size)
-            labels: tensor of size (batch_size)
-        Does any necessary preprocessing, then does mining, and then checks the
-        shape of the mining output before returning it
-        """
-        self.reset_stats()
-        with torch.no_grad():
-            c_f.check_shapes(embeddings, labels)
-            labels = c_f.to_device(labels, embeddings)
-            ref_emb, ref_labels = c_f.set_ref_emb(
-                embeddings, labels, ref_emb, ref_labels
-            )
-            mining_output = self.mine(embeddings, labels, ref_emb, ref_labels)
-        self.output_assertion(mining_output)
-        return mining_output
-
-
-class BaseTupleMiner(BaseMiner):
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
         self.add_to_recordable_attributes(
@@ -39,6 +12,9 @@ class BaseTupleMiner(BaseMiner):
             is_stat=True,
         )
 
+    def mine(self, embeddings, labels, ref_emb, ref_labels):
+        raise NotImplementedError
+
     def output_assertion(self, output):
         """
         Args:
@@ -60,17 +36,21 @@ class BaseTupleMiner(BaseMiner):
         else:
             raise TypeError
 
-
-class BaseSubsetBatchMiner(BaseMiner):
-    """
-    Args:
-        output_batch_size: type int. The size of the subset that the miner
-                            will output.
-    """
-
-    def __init__(self, output_batch_size, **kwargs):
-        super().__init__(**kwargs)
-        self.output_batch_size = output_batch_size
-
-    def output_assertion(self, output):
-        assert len(output) == self.output_batch_size
+    def forward(self, embeddings, labels, ref_emb=None, ref_labels=None):
+        """
+        Args:
+            embeddings: tensor of size (batch_size, embedding_size)
+            labels: tensor of size (batch_size)
+        Does any necessary preprocessing, then does mining, and then checks the
+        shape of the mining output before returning it
+        """
+        self.reset_stats()
+        with torch.no_grad():
+            c_f.check_shapes(embeddings, labels)
+            labels = c_f.to_device(labels, embeddings)
+            ref_emb, ref_labels = c_f.set_ref_emb(
+                embeddings, labels, ref_emb, ref_labels
+            )
+            mining_output = self.mine(embeddings, labels, ref_emb, ref_labels)
+        self.output_assertion(mining_output)
+        return mining_output
