@@ -1,8 +1,10 @@
-from .base_reducer import BaseReducer
 from .avg_non_zero_reducer import AvgNonZeroReducer
-from .mean_reducer import MeanReducer
-from .threshold_reducer import ThresholdReducer
-from .do_nothing_reducer import DoNothingReducer
-from .divisor_reducer import DivisorReducer
+from .base_reducer import BaseReducer
 from .class_weighted_reducer import ClassWeightedReducer
-from .multiple_reducers import MultipleReducers
\ No newline at end of file
+from .divisor_reducer import DivisorReducer
+from .do_nothing_reducer import DoNothingReducer
+from .mean_reducer import MeanReducer
+from .multiple_reducers import MultipleReducers
+from .per_anchor_reducer import PerAnchorReducer
+from .sum_reducer import SumReducer
+from .threshold_reducer import ThresholdReducer
