@@ -54,7 +54,7 @@ class HookContainer:
                 trainer.loss_tracker.loss_weights,
                 {"parent_name": "loss_weights"},
             ],
-            [trainer.loss_funcs, {"recursive_types": [torch.nn.Module]}],
+            [trainer.loss_funcs, {"recursive_types": [torch.nn.Module, dict]}],
             [trainer.mining_funcs, {}],
             [trainer.models, {}],
             [trainer.optimizers, {"custom_attr_func": self.optimizer_custom_attr_func}],
@@ -365,7 +365,14 @@ class HookContainer:
         )
         if reference_sets_label == query_set_label:
             reference_sets_label = "self"
-        return f"{base_record_group_name}_{query_set_label}_vs_{reference_sets_label}"
+        record_group_name = (
+            f"{base_record_group_name}_{query_set_label}_vs_{reference_sets_label}"
+        )
+        for key, val in self.record_keeper.hash_map.items():
+            if val == record_group_name:
+                record_group_name = key
+                break
+        return record_group_name
 
     def optimizer_custom_attr_func(self, optimizer):
         return {"lr": optimizer.param_groups[0]["lr"]}
